@@ -1,6 +1,6 @@
 # @file HelperFunctions.R
 #
-# Copyright 2020 Observational Health Data Sciences and Informatics
+# Copyright 2021 Observational Health Data Sciences and Informatics
 #
 # This file is part of SqlRender
 # 
@@ -78,17 +78,18 @@ writeSql <- function(sql, targetFile) {
 #' @details
 #' This function takes parameterized SQL and a list of parameter values and renders the SQL that can
 #' be send to the server. Parameterization syntax: \describe{ \item{@@parameterName}{Parameters are
-#' indicated using a @@ prefix, and are replaced with the actual values provided in the render
-#' call.} \item{\{DEFAULT @@parameterName = parameterValue\}}{Default values for parameters can be
-#' defined using curly and the DEFAULT keyword.} \item{\{if\}?\{then\}:\{else\}}{The if-then-else
-#' pattern is used to turn on or off blocks of SQL code.} }
+#' indicated using a @@ prefix, and are replaced with the actual values provided in the render call.}
+#' \item{\{DEFAULT @@parameterName = parameterValue\}}{Default values for parameters can be defined
+#' using curly and the DEFAULT keyword.} \item{\{if\}?\{then\}:\{else\}}{The if-then-else pattern is
+#' used to turn on or off blocks of SQL code.} }
 #'
 #'
-#' @param sourceFile   The source SQL file
-#' @param targetFile   The target SQL file
-#' @param warnOnMissingParameters     Should a warning be raised when parameters provided to this function 
-#'                                    do not appear in the parameterized SQL that is being rendered? By default, this is TRUE.
-#' @param ...          Parameter values
+#' @param sourceFile                The source SQL file
+#' @param targetFile                The target SQL file
+#' @param warnOnMissingParameters   Should a warning be raised when parameters provided to this
+#'                                  function do not appear in the parameterized SQL that is being
+#'                                  rendered? By default, this is TRUE.
+#' @param ...                       Parameter values
 #'
 #' @examples
 #' \dontrun{
@@ -109,11 +110,14 @@ renderSqlFile <- function(sourceFile, targetFile, warnOnMissingParameters = TRUE
 #' @details
 #' This function takes SQL and translates it to a different dialect.
 #'
-#' @param sourceFile         The source SQL file
-#' @param targetFile         The target SQL file
-#' @param targetDialect      The target dialect. Currently 'oracle', 'postgresql', and 'redshift' are
-#'                           supported
-#' @param oracleTempSchema   A schema that can be used to create temp tables in when using Oracle.
+#' @param sourceFile            The source SQL file
+#' @param targetFile            The target SQL file
+#' @param targetDialect         The target dialect. Currently "oracle", "postgresql", "pdw", "impala",
+#'                              "sqlite", "netezza", "bigquery", and "redshift" are supported.
+#' @param oracleTempSchema      DEPRECATED: use \code{tempEmulationSchema} instead.
+#' @param tempEmulationSchema   Some database platforms like Oracle and Impala do not truly support
+#'                              temp tables. To emulate temp tables, provide a schema with write
+#'                              privileges where temp tables can be created.
 #'
 #' @examples
 #' \dontrun{
@@ -125,9 +129,18 @@ renderSqlFile <- function(sourceFile, targetFile, warnOnMissingParameters = TRUE
 translateSqlFile <- function(sourceFile,
                              targetFile,
                              targetDialect,
+                             tempEmulationSchema = getOption("sqlRenderTempEmulationSchema"),
                              oracleTempSchema = NULL) {
+  if (!is.null(oracleTempSchema) && oracleTempSchema != "") {
+    warn("The 'oracleTempSchema' argument is deprecated. Use 'tempEmulationSchema' instead.",
+         .frequency = "regularly",
+         .frequency_id = "oracleTempSchema")
+    tempEmulationSchema <- oracleTempSchema
+  }
   sql <- readSql(sourceFile)
-  sql <- translate(sql = sql, targetDialect = targetDialect, oracleTempSchema = oracleTempSchema)
+  sql <- translate(sql = sql,
+                   targetDialect = targetDialect,
+                   tempEmulationSchema = tempEmulationSchema)
   writeSql(sql, targetFile)
 }
 
@@ -140,19 +153,23 @@ translateSqlFile <- function(sourceFile,
 #' @details
 #' This function looks for a SQL file with the specified name in the inst/sql/<dbms> folder of the
 #' specified package. If it doesn't find it in that folder, it will try and load the file from the
-#' inst/sql/sql_server folder and use the \code{translate} function to translate it to the
-#' requested dialect. It will subsequently call the \code{render} function with any of the
-#' additional specified parameters.
+#' inst/sql/sql_server folder and use the \code{translate} function to translate it to the requested
+#' dialect. It will subsequently call the \code{render} function with any of the additional specified
+#' parameters.
 #'
 #'
-#' @param sqlFilename                 The source SQL file
-#' @param packageName                 The name of the package that contains the SQL file
-#' @param dbms                        The target dialect. Currently 'sql server', 'oracle', 'postgres', and
-#'                                    'redshift' are supported
-#' @param ...                         Parameter values used for \code{render}
-#' @param oracleTempSchema            A schema that can be used to create temp tables in when using Oracle.
-#' @param warnOnMissingParameters     Should a warning be raised when parameters provided to this function 
-#'                                    do not appear in the parameterized SQL that is being rendered? By default, this is TRUE.
+#' @param sqlFilename               The source SQL file
+#' @param packageName               The name of the package that contains the SQL file
+#' @param dbms                      The target dialect. Currently 'sql server', 'oracle', 'postgres',
+#'                                  and 'redshift' are supported
+#' @param ...                       Parameter values used for \code{render}
+#' @param oracleTempSchema          DEPRECATED: use \code{tempEmulationSchema} instead.
+#' @param tempEmulationSchema       Some database platforms like Oracle and Impala do not truly support
+#'                                  temp tables. To emulate temp tables, provide a schema with write
+#'                                  privileges where temp tables can be created.
+#' @param warnOnMissingParameters   Should a warning be raised when parameters provided to this
+#'                                  function do not appear in the parameterized SQL that is being
+#'                                  rendered? By default, this is TRUE.
 #'
 #' @return
 #' Returns a string containing the rendered SQL.
@@ -168,8 +185,15 @@ loadRenderTranslateSql <- function(sqlFilename,
                                    packageName,
                                    dbms = "sql server",
                                    ...,
+                                   tempEmulationSchema = getOption("sqlRenderTempEmulationSchema"),
                                    oracleTempSchema = NULL,
                                    warnOnMissingParameters = TRUE) {
+  if (!is.null(oracleTempSchema) && oracleTempSchema != "") {
+    rlang::warn("The 'oracleTempSchema' argument is deprecated. Use 'tempEmulationSchema' instead.",
+                .frequency = "regularly",
+                .frequency_id = "oracleTempSchema")
+    tempEmulationSchema <- oracleTempSchema
+  }
   pathToSql <- system.file(paste("sql/", gsub(" ", "_", dbms), sep = ""),
                            sqlFilename,
                            package = packageName)
@@ -180,15 +204,23 @@ loadRenderTranslateSql <- function(sqlFilename,
                              sqlFilename,
                              package = packageName)
     if (!file.exists(pathToSql)) {
-       stop("Cannot find '", sqlFilename, "' in the 'sql/sql_server' folder of the '", packageName , "' package.") 
+      abort(paste0("Cannot find '",
+                   sqlFilename,
+                   "' in the 'sql/sql_server' folder of the '",
+                   packageName,
+                   "' package."))
     }
   }
   parameterizedSql <- readChar(pathToSql, file.info(pathToSql)$size)
   
-  renderedSql <- render(sql = parameterizedSql[1], warnOnMissingParameters = warnOnMissingParameters, ...)
+  renderedSql <- render(sql = parameterizedSql[1],
+                        warnOnMissingParameters = warnOnMissingParameters,
+                        ...)
   
   if (mustTranslate)
-    renderedSql <- translate(sql = renderedSql, targetDialect = dbms, oracleTempSchema = oracleTempSchema)
+    renderedSql <- translate(sql = renderedSql,
+                             targetDialect = dbms,
+                             tempEmulationSchema = tempEmulationSchema)
   
   renderedSql
 }
@@ -299,14 +331,14 @@ createRWrapperForSql <- function(sqlFilename,
                            sqlFilename,
                            package = packageName)
   if (file.exists(pathToSql)) {
-    writeLines(paste("Reading SQL from package folder:", pathToSql))
+    inform(paste("Reading SQL from package folder:", pathToSql))
     parameterizedSql <- readSql(pathToSql)
   } else if (file.exists(sqlFilename)) {
-    writeLines(paste("Reading SQL from current folder:", file.path(getwd(), sqlFilename)))
-    writeLines("Note: make sure the SQL file is placed in the /inst/sql/sql_server folder when building the package")
+    inform(paste("Reading SQL from current folder:", file.path(getwd(), sqlFilename)))
+    inform("Note: make sure the SQL file is placed in the /inst/sql/sql_server folder when building the package")
     parameterizedSql <- readSql(sqlFilename)
   } else {
-    stop("Could not find SQL file")
+    abort("Could not find SQL file")
   }
   
   hasTempTables <- any(gregexpr("\\#", parameterizedSql)[[1]] != -1)
@@ -327,18 +359,6 @@ createRWrapperForSql <- function(sqlFilename,
     c(sqlParameter = parameter, rParameter = ccParameter, value = value)
   }
   definitions <- as.data.frame(t(apply(hits, 1, FUN = f)))
-  databaseSchemaParameters <- definitions[grepl("database_schema$", definitions$sqlParameter), ]
-  databaseParameters <- c()
-  for (databaseSchemaParameter in databaseSchemaParameters$sqlParameter) {
-    databaseParameter <- substr(databaseSchemaParameter,
-                                1,
-                                nchar(databaseSchemaParameter) - nchar("_schema"))
-    if (any(definitions[, 1] == databaseParameter))
-      databaseParameters <- rbind(databaseParameters,
-                                  definitions[definitions$sqlParameter == databaseParameter,
-                                              ])
-  }
-  functionDefinitions <- definitions[!(definitions$sqlParameter %in% databaseParameters$sqlParameter), ]
   
   lines <- c()
   if (createRoxygenTemplate) {
@@ -354,9 +374,9 @@ createRWrapperForSql <- function(sqlFilename,
                "#' @param connectionDetails\t\tAn R object of type \\code{ConnectionDetails} created using the function \\code{createConnectionDetails} in the \\code{DatabaseConnector} package.")
     if (hasTempTables)
       lines <- c(lines,
-                 "#' @param oracleTempSchema\t\tA schema where temp tables can be created in Oracle.")
-    for (i in 1:nrow(functionDefinitions)) {
-      lines <- c(lines, paste("#' @param", functionDefinitions$rParameter[i], "\t\t"))
+                 "#' @param tempEmulationSchema\t\tSome database platforms like Oracle and Impala do not truly support temp tables. To emulate temp tables, provide a schema with write privileges where temp tables can be created.")
+    for (i in 1:nrow(definitions)) {
+      lines <- c(lines, paste("#' @param", definitions$rParameter[i], "\t\t"))
     }
     lines <- c(lines, "#'")
     lines <- c(lines, "#' @export")
@@ -364,32 +384,25 @@ createRWrapperForSql <- function(sqlFilename,
   lines <- c(lines,
              paste(gsub(".sql", "", sqlFilename), " <- function(connectionDetails,", sep = ""))
   if (hasTempTables)
-    lines <- c(lines, "                         oracleTempSchema = NULL,")
-  for (i in 1:nrow(functionDefinitions)) {
-    if (i == nrow(functionDefinitions))
+    lines <- c(lines,
+               "                         tempEmulationSchema = getOption(\"sqlRenderTempEmulationSchema\"),")
+  for (i in 1:nrow(definitions)) {
+    if (i == nrow(definitions))
       end <- ") {" else end <- ","
       lines <- c(lines, paste("                         ",
-                              functionDefinitions$rParameter[i],
+                              definitions$rParameter[i],
                               " = ",
-                              functionDefinitions$value[i],
+                              definitions$value[i],
                               end,
                               sep = ""))
   }
-  for (databaseParameter in databaseParameters$rParameter) {
-    lines <- c(lines, paste("  ",
-                            databaseParameter,
-                            " <- strsplit(",
-                            databaseParameter,
-                            "Schema ,\"\\\\.\")[[1]][1]",
-                            sep = ""))
-  }
   lines <- c(lines,
              paste("  renderedSql <- SqlRender::loadRenderTranslateSql(\"", sqlFilename, "\",",
                    sep = ""))
   lines <- c(lines, paste("              packageName = \"", packageName, "\",", sep = ""))
   lines <- c(lines, "              dbms = connectionDetails$dbms,")
   if (hasTempTables)
-    lines <- c(lines, "              oracleTempSchema = oracleTempSchema,")
+    lines <- c(lines, "              tempEmulationSchema = tempEmulationSchema,")
   for (i in 1:nrow(definitions)) {
     if (i == nrow(definitions))
       end <- ")" else end <- ","
@@ -400,15 +413,15 @@ createRWrapperForSql <- function(sqlFilename,
                               end,
                               sep = ""))
   }
-  lines <- c(lines, "  conn <- DatabaseConnector::connect(connectionDetails)")
+  lines <- c(lines, "  connection <- DatabaseConnector::connect(connectionDetails)")
+  lines <- c(lines, "  on.exit(DatabaseConnector::disconnect(connection))")
   lines <- c(lines, "")
   lines <- c(lines, "  writeLines(\"Executing multiple queries. This could take a while\")")
-  lines <- c(lines, "  DatabaseConnector::executeSql(conn,renderedSql)")
+  lines <- c(lines, "  DatabaseConnector::executeSql(connection,renderedSql)")
   lines <- c(lines, "  writeLines(\"Done\")")
   lines <- c(lines, "")
-  lines <- c(lines, "  dummy <- RJDBC::dbDisconnect(conn)")
   lines <- c(lines, "}")
-  writeLines(paste("Writing R function to:", rFilename))
+  inform(paste("Writing R function to:", rFilename))
   sink(rFilename)
   cat(paste(lines, collapse = "\n"))
   sink()
