@@ -33,8 +33,8 @@ dashboardPage(
              box(background = "light-blue",
                  h4("Target dialect"), width = NULL,
                  selectInput("dialect", NULL, choices = c("BigQuery", "Impala", "Netezza", "Oracle", "PDW", "PostgreSQL", "RedShift", "SQL Server", "SQLite", "Hive"), selected = "SQL Server"),
-                 h4("Oracle temp schema"),
-                 textInput("oracleTempSchema", NULL),
+                 h4("Temp emulation schema"),
+                 textInput("tempEmulationSchema", NULL),
                  h4("Parameters"),
                  uiOutput("parameterInputs"),
                  textOutput("warnings")
