@@ -4,9 +4,9 @@ public class TestSqlRender {
 
 	public static void main(String[] args) {
 		
-		String sql = "CONCAT( CONCAT( field1, ' and ' ), field2 )";
+		String sql = "WITH data(x) AS (SELECT (CAST(1 AS INT) x)) SELECT x INTO my_table FROM data;";
 		String path = "inst/csv/replacementPatterns.csv";
-		sql = SqlTranslate.translateSqlWithPath(sql, "netezza", null, null, path);
+		sql = SqlTranslate.translateSqlWithPath(sql, "bigquery", null, null, path);
 		System.out.println(sql);
 		
 //		Pattern pattern = Pattern.compile("^((?!FROM).)*$");
