@@ -30,14 +30,26 @@ test_that("translateSqlFile", {
   sql2 <- readSql(fileName2)
   file.remove(fileName1)
   file.remove(fileName2)
-  expect_equal(sql2, "SELECT (observation_period_start_date + 1*INTERVAL'1 day') FROM observation_period")
+  expect_equal(sql2,
+               "SELECT (observation_period_start_date + 1*INTERVAL'1 day') FROM observation_period")
+})
+
+test_that("Warning in translateSqlFile when using oracleTempSchema", {
+  fileName1 <- tempfile()
+  fileName2 <- tempfile()
+  sql1 <- "SELECT DATEADD(dd,1,observation_period_start_date) FROM observation_period"
+  writeSql(sql1, fileName1)
+  clearWarningBlock()
+  expect_warning(translateSqlFile(fileName1, fileName2, targetDialect = "oracle", oracleTempSchema = "scratch"))
+  file.remove(fileName1)
+  file.remove(fileName2)
 })
 
 test_that("snakeCaseToCamelCase", {
   string1 <- "cdm_database_schema"
   string2 <- snakeCaseToCamelCase(string1)
   expect_equal(string2, "cdmDatabaseSchema")
-
+  
   string1 <- "EXPOSURE_ID_1"
   string2 <- snakeCaseToCamelCase(string1)
   expect_equal(string2, "exposureId1")
@@ -66,20 +78,27 @@ test_that("camelCaseToTitleCase ", {
 test_that("loadRenderTranslateSql ", {
   sql <- loadRenderTranslateSql("test.sql", "SqlRender", "sql server")
   sql <- gsub("[\r\n]", "", sql)
-  expect_equal(sql, "SELECT * FROM table;")
-
+  expect_equal(sql, "SELECT a FROM #my_table WHERE my_id = 123;")
+  
   sql <- loadRenderTranslateSql("test.sql", "SqlRender", "postgresql")
   sql <- gsub("[\r\n]", "", sql)
-  expect_equal(sql, "SELECT * FROM table;")
-
+  expect_equal(sql, "SELECT a FROM my_table WHERE my_id = 123;")
+  
   sql <- loadRenderTranslateSql("test.sql", "SqlRender", "oracle")
   sql <- gsub("[\r\n]", "", sql)
-  expect_equal(sql, "SELECT a FROM table;")
+  expect_equal(sql, "SELECT a FROM my_table WHERE my_id = 123;")
 })
 
+test_that("Warning using loadRenderTranslateSql with oracleTempSchema", {
+  clearWarningBlock()
+  expect_warning(loadRenderTranslateSql(sqlFilename = "test.sql", packageName = "SqlRender", dbms = "oracle", oracleTempSchema = "scratch"))
+})
+
+
+
 test_that("createRWrapperForSql", {
   fileName <- tempfile()
-  createRWrapperForSql("test.sql", fileName, "SqlRender", createRoxygenTemplate = TRUE)
+  createRWrapperForSql(sqlFilename = "test.sql", rFilename = fileName, packageName = "SqlRender", createRoxygenTemplate = TRUE)
   expect_true(file.exists(fileName))
   file.remove(fileName)
 })
